@@ -35,12 +35,18 @@ sub awx_wx_config_data {
     my $orig_libdir;
     my $final = $self->awx_debug ? 'BUILD=debug   DEBUG_RUNTIME_LIBS=0'
                                  : 'BUILD=release DEBUG_RUNTIME_LIBS=0';
+
+	if( my $xbuildflags = $self->awx_w32_extra_buildflags ) {
+		$final .= ' ' . $xbuildflags;
+	}
+    
     my $unicode = $self->awx_unicode ? 'UNICODE=1' : 'UNICODE=0';
     $unicode .= ' MSLU=1' if $self->awx_mslu;
 
     my $dir = Cwd::cwd;
     chdir File::Spec->catdir( $ENV{WXDIR}, 'samples', 'minimal' );
-    my @t = qx(nmake /nologo /n /u /f makefile.vc $final $unicode SHARED=1);
+
+    my @t = qx(nmake /nologo /n /a /u /f makefile.vc $final $unicode SHARED=1);
 
     my( $accu, $libdir, $digits );
     foreach ( @t ) {
@@ -70,6 +76,8 @@ sub awx_wx_config_data {
     chdir $dir;
     die 'Could not find wxWidgets lib directory' unless $libdir;
 
+    $self->awx_w32_find_setup_dir( $data{cxxflags} ); # for awx_grep_dlls
+
     $data{dlls} = $self->awx_grep_dlls( $orig_libdir, $digits, $self->awx_is_monolithic );
     $data{version} = $digits;
 
@@ -80,8 +88,44 @@ sub _make_command { "nmake -f makefile.vc all " }
 
 sub build_wxwidgets {
     my( $self ) = shift;
+    my $old_dir = Cwd::cwd();
 
     $self->My::Build::Win32_Bakefile::build_wxwidgets( @_ );
+
+    # Compiling with MSVC 9 (VS 2008) and probably with VS 2005, the
+    # linker creates a manifest that must be embedded in the DLL to
+    # make it load correctly
+    chdir File::Spec->catdir( $ENV{WXDIR} );
+    foreach my $dll ( glob( 'lib/vc_dll*/*.dll' ) ) {
+        next unless -f "${dll}.manifest";
+        $self->_system( 'mt', '-nologo', '-manifest', "${dll}.manifest",
+                        "-outputresource:${dll};2" );
+        unlink "${dll}.manifest";
+    }
+
+    chdir $old_dir;
 }
 
+
+sub awx_w32_ldflags {
+	my $self = shift;
+	my $ldflags = '';
+	
+	# security cookie lib for Platform SDK 2003
+	# ActivePerl will configure $Config{libs}
+	# according to cl version.
+	# For other MSVC built Perl, we'll assume
+	# same cl as built Perl is building wxWidgets
+	
+	my $libs = $Config{libs};
+	if($libs =~ /bufferoverflowU\.lib/i) {
+		$ldflags = 'bufferoverflowU.lib';
+	}
+	
+	return $ldflags;
+	
+}
+
+sub awx_w32_cppflags { return ''; }
+
 1;
